interface BaseTask<Results, Data> {
    /** The state of the task */
    state: 'idle' | 'pending';
    /** A function to run */
    run: () => Promise<Results>;
    /** other metadata about the task */
    data?: Data;
}
export declare type CompletedTask<Results, Data> = Omit<BaseTask<Results, Data>, 'state'> & {
    /** The state of the task */
    state: 'completed';
} & ({
    /** The results */
    output: Results;
    /** An error if any */
    error?: never;
} | {
    /** The error if any */
    error: Error;
    /** No output on error */
    output?: never;
});
export declare type Task<ResultsType, Data> = BaseTask<ResultsType, Data> | CompletedTask<ResultsType, Data>;
export interface TaskProgressRenderer<ResultType, Data = unknown> {
    /** Call back to paint update on the page */
    onUpdate: (ctx: {
        /** The tasks that are running */
        tasks: Array<Task<ResultType, Data>>;
    }) => string;
    /** Called for a summary */
    onEnd: (ctx: {
        /** The completed tasks */
        tasks: Array<CompletedTask<ResultType, Data>>;
        /** Number of ms it took to run */
        duration: number;
    }) => string;
}
interface TaskRunner<R, Data> {
    /** The list of tasks */
    tasks: Array<Task<R, Data>>;
    /** A trigger to start it */
    run: () => Promise<Array<CompletedTask<R, Data>>>;
}
/** Create a runner to kick off tasks in parallel */
export declare const createTaskRunner: <R, D>({ tasks, renderer, }: {
    /** A list of tasks to run */
    tasks: Pick<BaseTask<R, D>, "run" | "data">[];
    /** How to report progress */
    renderer: TaskProgressRenderer<R, D>;
}) => TaskRunner<R, D>;
export {};
//# sourceMappingURL=task-runner.d.ts.map